#include "MutexLock.h"

unsigned int MutexLockBase::usleep_granularity=5000;

#ifndef PLATFORM_APERIOS
SemaphoreManager MutexLockBase::preallocated;
SemaphoreManager* MutexLockBase::semgr=&preallocated;
ThreadNS::Lock MutexLockBase::thdLocks[SemaphoreManager::MAX_SEM];
#endif

/*! @file 
* @brief Defines MutexLock, a software only mutual exclusion lock.
* @author ejt (Creator), Edward A. Lycklama, Vassos Hadzilacos (paper from which this was based)
*
* $Author: ejt $
* $Name: tekkotsu-3_0 $
* $Revision: 1.3 $
* $State: Exp $
* $Date: 2006/05/08 22:07:54 $
*/
